pub struct CapacityOverflow;Available on crate features
collections and linked only.Expand description
TODO
Note: This error is no longer returned by any public part of the API, but it is thrown during panics. This is because a capacity overflow has such a small chance of occurring that it isn’t worth handling in most placed. Most machines wouldn’t have enough memory to overflow a non-ZST collection with a u64 length.